@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2017	PgPool Global Development Group
+ * Copyright (c) 2003-2014	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -130,7 +130,7 @@ void do_child(int unix_fd, int inet_fd)
 	signal(SIGPIPE, SIG_IGN);
 
 #ifdef NONE_BLOCK
-	/* set listen fds to none block */
+	/* set listen fds to none-blocking */
 	pool_set_nonblock(unix_fd);
 	if (inet_fd)
 	{
@@ -287,7 +287,7 @@ void do_child(int unix_fd, int inet_fd)
 		}
 
 		/*
-		 * Ok, negotiaton with frontend has been done. Let's go to the
+		 * Ok, negotiation with frontend has been done. Let's go to the
 		 * next step.  Connect to backend if there's no existing
 		 * connection which can be reused by this frontend.
 		 * Authentication is also done in this step.
@@ -371,13 +371,7 @@ void do_child(int unix_fd, int inet_fd)
 		 */
 		pool_init_session_context(frontend, backend);
 
-		/*
-		 * Set protocol versions
-		 */
-		pool_set_major_version(sp->major);
-		pool_set_minor_version(sp->minor);
-
-		/* Mark this connection pool is conncted from frontend */
+		/* Mark this connection pool is connected from frontend */
 		pool_coninfo_set_frontend_connected(pool_get_process_context()->proc_id, pool_pool_index());
 
 		/* query process loop */
@@ -434,14 +428,14 @@ void do_child(int unix_fd, int inet_fd)
 					}
 					break;
 
-				/* error occured. discard backend connection pool
+				/* error occurred. discard backend connection pool
                    and disconnect connection to the frontend */
 				case POOL_ERROR:
 					pool_log("do_child: exits with status 1 due to error");
 					child_exit(1);
 					break;
 
-				/* fatal error occured. just exit myself... */
+				/* fatal error occurred. just exit myself... */
 				case POOL_FATAL:
 					notice_backend_error(1);
 					child_exit(1);
@@ -464,7 +458,7 @@ void do_child(int unix_fd, int inet_fd)
 		/* Destroy session context */
 		pool_session_context_destroy();
 
-		/* Mark this connection pool is not conncted from frontend */
+		/* Mark this connection pool is not connected from frontend */
 		pool_coninfo_unset_frontend_connected(pool_get_process_context()->proc_id, pool_pool_index());
 
 		accepted = 0;
@@ -553,7 +547,7 @@ static POOL_CONNECTION *do_accept(int unix_fd, int inet_fd, struct timeval *time
 
 	/*
 	 * following code fragment computes remaining timeout val in a
-	 * portable way. Linux does this automazically but other platforms do not.
+	 * portable way. Linux does this automatically but other platforms do not.
 	 */
 	if (timeoutval)
 	{
@@ -817,7 +811,7 @@ static POOL_CONNECTION *do_accept(int unix_fd, int inet_fd, struct timeval *time
 		return NULL;
 	}
 
-	/* save ip addres for hba */
+	/* save ip address for hba */
 	memcpy(&cp->raddr, &saddr, sizeof(SockAddr));
 	if (cp->raddr.addr.ss_family == 0)
 		cp->raddr.addr.ss_family = AF_UNIX;
@@ -847,7 +841,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 
 	if (pool_config->authentication_timeout > 0)
 	{
-		pool_alarm(authentication_timeout, pool_config->authentication_timeout);
+		pool_signal(SIGALRM, authentication_timeout);
+		alarm(pool_config->authentication_timeout);
 	}
 
 	/* read startup packet length */
@@ -855,7 +850,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	{
 		pool_error("read_startup_packet: incorrect packet length (%d)", len);
 		pool_free_startup_packet(sp);
-		pool_undo_alarm();
+		alarm(0);
+		pool_signal(SIGALRM, SIG_IGN);
 		return NULL;
 	}
 	len = ntohl(len);
@@ -865,7 +861,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	{
 		pool_error("read_startup_packet: incorrect packet length (%d)", len);
 		pool_free_startup_packet(sp);
-		pool_undo_alarm();
+		alarm(0);
+		pool_signal(SIGALRM, SIG_IGN);
 		return NULL;
 	}
 
@@ -874,7 +871,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	{
 		pool_error("read_startup_packet: out of memory");
 		pool_free_startup_packet(sp);
-		pool_undo_alarm();
+		alarm(0);
+		pool_signal(SIGALRM, SIG_IGN);
 		return NULL;
 	}
 
@@ -882,7 +880,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 	if (pool_read(cp, sp->startup_packet, len))
 	{
 		pool_free_startup_packet(sp);
-		pool_undo_alarm();
+		alarm(0);
+		pool_signal(SIGALRM, SIG_IGN);
 		return NULL;
 	}
 
@@ -902,7 +901,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				pool_undo_alarm();
+				alarm(0);
+				pool_signal(SIGALRM, SIG_IGN);
 				return NULL;
 			}
 			strncpy(sp->database, sp2->database, SM_DATABASE);
@@ -912,7 +912,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				pool_undo_alarm();
+				alarm(0);
+				pool_signal(SIGALRM, SIG_IGN);
 				return NULL;
 			}
 			strncpy(sp->user, sp2->user, SM_USER);
@@ -932,7 +933,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 					{
 						pool_error("read_startup_packet: out of memory");
 						pool_free_startup_packet(sp);
-						pool_undo_alarm();
+						alarm(0);
+						pool_signal(SIGALRM, SIG_IGN);
 						return NULL;
 					}
 				}
@@ -944,7 +946,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 					{
 						pool_error("read_startup_packet: out of memory");
 						pool_free_startup_packet(sp);
-						pool_undo_alarm();
+						alarm(0);
+						pool_signal(SIGALRM, SIG_IGN);
 						return NULL;
 					}
 				}
@@ -977,7 +980,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				pool_undo_alarm();
+				alarm(0);
+				pool_signal(SIGALRM, SIG_IGN);
 				return NULL;
 			}
 			sp->user = calloc(1, 1);
@@ -985,7 +989,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 			{
 				pool_error("read_startup_packet: out of memory");
 				pool_free_startup_packet(sp);
-				pool_undo_alarm();
+				alarm(0);
+				pool_signal(SIGALRM, SIG_IGN);
 				return NULL;
 			}
 			break;
@@ -993,7 +998,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 		default:
 			pool_error("read_startup_packet: invalid major no: %d", sp->major);
 			pool_free_startup_packet(sp);
-			pool_undo_alarm();
+			alarm(0);
+			pool_signal(SIGALRM, SIG_IGN);
 			return NULL;
 	}
 
@@ -1008,7 +1014,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 								__FILE__, __LINE__);
 		pool_error("read_startup_packet: no PostgreSQL user name specified in startup packet");
 		pool_free_startup_packet(sp);
-		pool_undo_alarm();
+		alarm(0);
+		pool_signal(SIGALRM, SIG_IGN);
 		return NULL;
 	}
 
@@ -1020,7 +1027,8 @@ static StartupPacket *read_startup_packet(POOL_CONNECTION *cp)
 
 	pool_debug("Protocol Major: %d Minor: %d database: %s user: %s",
 			   sp->major, sp->minor, sp->database, sp->user);
-	pool_undo_alarm();
+	alarm(0);
+	pool_signal(SIGALRM, SIG_IGN);
 	return sp;
 }
 
@@ -1207,7 +1215,7 @@ void cancel_request(CancelPacket *sp)
 		pool_close(con);
 
 		/*
-		 * this is needed to enure that the next DB node executes the
+		 * this is needed to ensure that the next DB node executes the
 		 * query supposed to be canceled.
 		 */
 		sleep(1);
@@ -1235,7 +1243,7 @@ static POOL_CONNECTION_POOL *connect_backend(StartupPacket *sp, POOL_CONNECTION
 		if (VALID_BACKEND(i))
 		{
 			/* set DB node id */
-			pool_set_db_node_id(CONNECTION(backend, i), i);
+			CONNECTION(backend, i)->db_node_id = i;
 
 			/* mark this is a backend connection */
 			CONNECTION(backend, i)->isbackend = 1;
@@ -1285,19 +1293,15 @@ static RETSIGTYPE die(int sig)
 			/* Refuse further requests by closing listen socket */
 			if (child_inet_fd)
 			{
-#ifdef NOT_USED
 				pool_log("die: close listen socket");
-#endif
 				close(child_inet_fd);
 			}
 			close(child_unix_fd);
 
-#ifdef NOT_USED
 			if (idle == 0)
 			{
 				pool_debug("child receives smart shutdown request but it's not in idle state");
 			}
-#endif
 			break;
 
 		case SIGINT:	/* fast shutdown */
@@ -1305,9 +1309,7 @@ static RETSIGTYPE die(int sig)
 			child_exit(0);
 			break;
 		default:
-#ifdef NOT_USED
 			pool_error("die() received unknown signal: %d", sig);
-#endif
 			break;
 	}
 }
@@ -1322,9 +1324,7 @@ static RETSIGTYPE close_idle_connection(int sig)
 	POOL_CONNECTION_POOL *p = pool_connection_pool;
 	ConnectionInfo *info;
 
-#ifdef NOT_USED
 	pool_debug("child receives close connection request");
-#endif
 
 	for (j=0;j<pool_config->max_pool;j++, p++)
 	{
@@ -1449,9 +1449,7 @@ void child_exit(int code)
 {
 	if (getpid() == mypid)
 	{
-#ifdef NOT_USED
 		pool_log("child_exit: called from pgpool main. ignored.");
-#endif
 		return;
 	}
 
@@ -1484,7 +1482,7 @@ void child_exit(int code)
  * create a persistent connection
  */
 POOL_CONNECTION_POOL_SLOT *make_persistent_db_connection(
-	int db_node_id, char *hostname, int port, char *dbname, char *user, char *password, bool retry)
+	char *hostname, int port, char *dbname, char *user, char *password, bool retry)
 {
 	POOL_CONNECTION_POOL_SLOT *cp;
 	int fd;
@@ -1542,7 +1540,6 @@ POOL_CONNECTION_POOL_SLOT *make_persistent_db_connection(
 	cp->con = pool_open(fd);
 	cp->closetime = 0;
 	cp->con->isbackend = 1;
-	pool_set_db_node_id(cp->con, db_node_id);
 	pool_ssl_negotiate_clientserver(cp->con);
 
 	/*
@@ -1838,7 +1835,7 @@ static int s_do_auth(POOL_CONNECTION_POOL_SLOT *cp, char *password)
 	}
 
 	/*
-	 * Read backend key data and wait until Reay for query arriving or
+	 * Read backend key data and wait until Ready for query arriving or
 	 * error happens.
 	 */
 
@@ -2083,7 +2080,7 @@ static void init_system_db_connection(void)
 			pool_error("Could not make persistent libpq system DB connection");
 		}
 
-		system_db_info->connection = make_persistent_db_connection(-1, pool_config->system_db_hostname,
+		system_db_info->connection = make_persistent_db_connection(pool_config->system_db_hostname,
 																   pool_config->system_db_port,
 																   pool_config->system_db_dbname,
 																   pool_config->system_db_user,
