@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2016	PgPool Global Development Group
+ * Copyright (c) 2003-2014	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -126,7 +126,7 @@ typedef struct
 typedef struct CancelPacket
 {
 	int			protoVersion;		/* Protocol version */
-	int			pid;	/* bcckend process id */
+	int			pid;	/* backend process id */
 	int			key;	/* cancel key */
 } CancelPacket;
 
@@ -189,7 +189,7 @@ typedef struct {
 	char salt[4];		/* password salt */
 
 	/*
-	 * following are used to remember current session paramter status.
+	 * following are used to remember current session parameter status.
 	 * re-used connection will need them (V3 only)
 	 */
 	ParamStatus params;
@@ -303,7 +303,6 @@ extern int my_master_node_id;
  */
 #define PRIMARY_NODE_ID (Req_info->primary_node_id >=0?\
 						 Req_info->primary_node_id:REAL_MASTER_NODE_ID)
-#define IS_PRIMARY_NODE_ID(node_id)	(node_id == PRIMARY_NODE_ID)
 
 /*
  * Real primary node id. If not in the mode or there's no primary
@@ -323,12 +322,10 @@ extern int my_master_node_id;
 
 #define REPLICATION (pool_config->replication_mode)
 #define MASTER_SLAVE (pool_config->master_slave_mode)
-#define STREAM (MASTER_SLAVE && !strcmp("stream", pool_config->master_slave_sub_mode))
-#define SLONY (MASTER_SLAVE && !strcmp("slony", pool_config->master_slave_sub_mode))
 #define DUAL_MODE (REPLICATION || MASTER_SLAVE)
 #define PARALLEL_MODE (pool_config->parallel_mode)
 #define RAW_MODE (!REPLICATION && !PARALLEL_MODE && !MASTER_SLAVE)
-#define MAJOR(p) (pool_get_major_version())
+#define MAJOR(p) MASTER_CONNECTION(p)->sp->major
 #define TSTATE(p, i) (CONNECTION(p, i)->tstate)
 #define INTERNAL_TRANSACTION_STARTED(p, i) (CONNECTION(p, i)->is_internal_transaction_started)
 #define SYSDB_INFO (system_db_info->info)
@@ -384,7 +381,7 @@ typedef struct {
 /* description of row. corresponding to RowDescription message */
 typedef struct {
 	char *attrname;		/* attribute name */
-	int oid;	/* 0 or non 0 if it's a table oblect */
+	int oid;	/* 0 or non 0 if it's a table object */
 	int attrnumber;		/* attribute number starting with 1. 0 if it's not a table */
 	int typeoid;		/* data type oid */
 	int	size;	/* data length minus means variable data type */
@@ -485,7 +482,6 @@ extern POOL_STATUS NoticeResponse(POOL_CONNECTION *frontend,
 
 extern void notice_backend_error(int node_id);
 extern void degenerate_backend_set(int *node_id_set, int count);
-extern bool degenerate_backend_set_ex(int *node_id_set, int count, bool test_only);
 extern void promote_backend(int node_id);
 extern void send_failback_request(int node_id);
 
@@ -556,7 +552,7 @@ extern POOL_STATUS OneNode_do_command(POOL_CONNECTION *frontend, POOL_CONNECTION
 
 /* child.c */
 extern POOL_CONNECTION_POOL_SLOT *make_persistent_db_connection(
-	int db_node_id, char *hostname, int port, char *dbname, char *user, char *password, bool retry);
+	char *hostname, int port, char *dbname, char *user, char *password, bool retry);
 extern void discard_persistent_db_connection(POOL_CONNECTION_POOL_SLOT *cp);
 
 /* define pool_system.c */
@@ -617,6 +613,7 @@ extern void free_select_result(POOL_SELECT_RESULT *result);
 extern int compare(const void *p1, const void *p2);
 extern POOL_STATUS do_error_execute_command(POOL_CONNECTION_POOL *backend, int node_id, int major);
 extern POOL_STATUS pool_discard_packet_contents(POOL_CONNECTION_POOL *cp);
+extern void pool_dump_valid_backend(int backend_id);
 
 /* pool_auth.c */
 extern void pool_random_salt(char *md5Salt);
